@@ -70,7 +70,7 @@ convertQuali <- function(x, to_class){
   if(to_class == "snellen"){
     to_class <- "snellenft"
   }
-  if (any(x %in% c("nlp", "lp", "hm", "cf"))) {
+  if (any(x %in% eye_codes$quali)) {
     x_quali <- va_chart[[to_class]][match(x, va_chart$quali[1:4])]
     x <- ifelse(!is.na(x_quali), x_quali, x)
   }
